@@ -4,10 +4,11 @@ import (
 	"fmt"
 	"runtime"
 	"strings"
-	"sync"
 	"sync/atomic" // Note: atomic.Bool was added at Go 1.19
 	"testing"
 	"time"
+
+	"golang.org/x/sys/execabs"
 )
 
 func testStartEchoCommand(t *testing.T, proc *concurrentProcess, done *atomic.Bool) {
@@ -35,64 +36,6 @@ func testSkipIfNoCommand(t *testing.T, p *concurrentProcess, cmd string) *extern
 	return c
 }
 
-func TestProcessRunProcessSerial(t *testing.T) {
-	p := newConcurrentProcess(1)
-	ret := []string{}
-	mu := sync.Mutex{}
-	starts := []time.Time{}
-	ends := []time.Time{}
-	numProcs := 3
-	echo := testSkipIfNoCommand(t, p, "echo")
-
-	for i := 0; i < numProcs; i++ {
-		in := fmt.Sprintf("message %d", i)
-		echo.run([]string{in}, "", func(b []byte, err error) error {
-			mu.Lock()
-			defer mu.Unlock()
-
-			starts = append(starts, time.Now())
-			defer func() {
-				ends = append(ends, time.Now())
-			}()
-
-			if err != nil {
-				t.Error(err)
-				return err
-			}
-
-			ret = append(ret, string(b))
-			return nil
-		})
-	}
-
-	if err := echo.wait(); err != nil {
-		t.Fatal(err)
-	}
-	p.wait()
-
-	if len(ret) != numProcs {
-		t.Fatalf("wanted %d outputs but got %#v", numProcs, ret)
-	}
-
-	// Check error messages
-	for i := 0; i < numProcs; i++ {
-		e := fmt.Sprintf("message %d", i)
-		if !strings.HasPrefix(ret[i], e) {
-			t.Fatalf("ret[%d] does not start with %q: %#v", i, e, ret)
-		}
-	}
-
-	starts = starts[1:]
-	ends = ends[:len(ends)-1]
-
-	for i, s := range starts {
-		e := ends[i]
-		if s.Before(e) {
-			t.Errorf("Command #%d started at %s before previous command #%d ends at %s", i+1, s, i, e)
-		}
-	}
-}
-
 func TestProcessRunConcurrently(t *testing.T) {
 	if runtime.GOOS == "windows" {
 		t.Skip("this test is flaky on Windows")
@@ -122,6 +65,35 @@ func TestProcessRunConcurrently(t *testing.T) {
 	}
 }
 
+func TestProcessRunWithArgs(t *testing.T) {
+	if _, err := execabs.LookPath("echo"); err != nil {
+		t.Skipf("echo command is necessary to run this test: %s", err)
+	}
+
+	var done atomic.Bool
+	p := newConcurrentProcess(1)
+	echo, err := p.newCommandRunner("echo hello", false)
+	if err != nil {
+		t.Fatalf(`parsing "echo hello" failed: %v`, err)
+	}
+	echo.run(nil, "", func(b []byte, err error) error {
+		if err != nil {
+			t.Error(err)
+			return err
+		}
+		if string(b) != "hello\n" {
+			t.Errorf("unexpected output: %q", b)
+		}
+		done.Store(true)
+		return nil
+	})
+	p.wait()
+
+	if !done.Load() {
+		t.Error("callback did not run")
+	}
+}
+
 func TestProcessRunMultipleCommandsConcurrently(t *testing.T) {
 	p := newConcurrentProcess(3)
 
